@@ -1,5 +1,5 @@
-// SPDX-FileCopyrightText: 2022 Kevin Matthes
 // SPDX-FileCopyrightText: 2022 Shun Sakai
+// SPDX-FileCopyrightText: 2023 Kevin Matthes
 //
 // SPDX-License-Identifier: Apache-2.0 OR MIT
 
@@ -7,16 +7,16 @@
 //!
 //! [`<sysexits.h>`]: https://man.openbsd.org/sysexits
 
+mod consts;
 mod convert;
+mod fmt;
 pub mod result;
 
-use core::fmt;
-
 /// `ExitCode` is a type that represents the system exit code constants as
 /// defined by [`<sysexits.h>`].
 ///
 /// [`<sysexits.h>`]: https://man.openbsd.org/sysexits
-#[derive(Clone, Copy, Debug, Eq, PartialEq)]
+#[derive(Clone, Copy, Debug, Default, Eq, PartialEq)]
 pub enum ExitCode {
     /// The successful exit.
     ///
@@ -25,8 +25,9 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::Ok as u8, 0);
+    /// assert_eq!(u8::from(ExitCode::Ok), 0);
     /// ```
+    #[default]
     Ok,
 
     /// The command was used incorrectly, e.g., with the wrong number of
@@ -37,7 +38,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::Usage as u8, 64);
+    /// assert_eq!(u8::from(ExitCode::Usage), 64);
     /// ```
     Usage = 64,
 
@@ -49,7 +50,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::DataErr as u8, 65);
+    /// assert_eq!(u8::from(ExitCode::DataErr), 65);
     /// ```
     DataErr,
 
@@ -62,7 +63,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::NoInput as u8, 66);
+    /// assert_eq!(u8::from(ExitCode::NoInput), 66);
     /// ```
     NoInput,
 
@@ -74,7 +75,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::NoUser as u8, 67);
+    /// assert_eq!(u8::from(ExitCode::NoUser), 67);
     /// ```
     NoUser,
 
@@ -86,7 +87,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::NoHost as u8, 68);
+    /// assert_eq!(u8::from(ExitCode::NoHost), 68);
     /// ```
     NoHost,
 
@@ -99,7 +100,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::Unavailable as u8, 69);
+    /// assert_eq!(u8::from(ExitCode::Unavailable), 69);
     /// ```
     Unavailable,
 
@@ -111,7 +112,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::Software as u8, 70);
+    /// assert_eq!(u8::from(ExitCode::Software), 70);
     /// ```
     Software,
 
@@ -125,7 +126,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::OsErr as u8, 71);
+    /// assert_eq!(u8::from(ExitCode::OsErr), 71);
     /// ```
     ///
     /// [`getuid(2)`]: https://man.openbsd.org/getuid.2
@@ -139,7 +140,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::OsFile as u8, 72);
+    /// assert_eq!(u8::from(ExitCode::OsFile), 72);
     /// ```
     OsFile,
 
@@ -150,7 +151,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::CantCreat as u8, 73);
+    /// assert_eq!(u8::from(ExitCode::CantCreat), 73);
     /// ```
     CantCreat,
 
@@ -161,7 +162,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::IoErr as u8, 74);
+    /// assert_eq!(u8::from(ExitCode::IoErr), 74);
     /// ```
     IoErr,
 
@@ -174,7 +175,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::TempFail as u8, 75);
+    /// assert_eq!(u8::from(ExitCode::TempFail), 75);
     /// ```
     TempFail,
 
@@ -186,7 +187,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::Protocol as u8, 76);
+    /// assert_eq!(u8::from(ExitCode::Protocol), 76);
     /// ```
     Protocol,
 
@@ -200,7 +201,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::NoPerm as u8, 77);
+    /// assert_eq!(u8::from(ExitCode::NoPerm), 77);
     /// ```
     NoPerm,
 
@@ -211,7 +212,7 @@ pub enum ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::Config as u8, 78);
+    /// assert_eq!(u8::from(ExitCode::Config), 78);
     /// ```
     Config,
 }
@@ -225,8 +226,8 @@ impl ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::Ok.is_success(), true);
-    /// assert_eq!(ExitCode::Usage.is_success(), false);
+    /// assert!(ExitCode::Ok.is_success());
+    /// assert!(!ExitCode::Usage.is_success());
     /// ```
     #[must_use]
     #[inline]
@@ -242,8 +243,8 @@ impl ExitCode {
     /// ```
     /// # use sysexits::ExitCode;
     /// #
-    /// assert_eq!(ExitCode::Ok.is_failure(), false);
-    /// assert_eq!(ExitCode::Usage.is_failure(), true);
+    /// assert!(!ExitCode::Ok.is_failure());
+    /// assert!(ExitCode::Usage.is_failure());
     /// ```
     #[must_use]
     #[inline]
@@ -265,28 +266,12 @@ impl ExitCode {
     /// }
     /// ```
     #[cfg(feature = "std")]
+    #[inline]
     pub fn exit(self) -> ! {
         std::process::exit(self.into())
     }
 }
 
-impl fmt::Display for ExitCode {
-    /// Shows the integer representation of this `ExitCode`.
-    ///
-    /// # Examples
-    ///
-    /// ```
-    /// # use sysexits::ExitCode;
-    /// #
-    /// assert_eq!(format!("{}", ExitCode::Ok), "0");
-    /// assert_eq!(format!("{}", ExitCode::Usage), "64");
-    /// ```
-    #[inline]
-    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        u8::from(*self).fmt(f)
-    }
-}
-
 #[cfg(feature = "std")]
 impl std::error::Error for ExitCode {}
 
@@ -303,40 +288,45 @@ mod tests {
     use super::*;
 
     #[test]
-    fn clone_exit_code() {
+    fn exit_code() {
+        assert_eq!(ExitCode::Ok as u8, 0);
+        assert_eq!(ExitCode::Usage as u8, 64);
+        assert_eq!(ExitCode::DataErr as u8, 65);
+        assert_eq!(ExitCode::NoInput as u8, 66);
+        assert_eq!(ExitCode::NoUser as u8, 67);
+        assert_eq!(ExitCode::NoHost as u8, 68);
+        assert_eq!(ExitCode::Unavailable as u8, 69);
+        assert_eq!(ExitCode::Software as u8, 70);
+        assert_eq!(ExitCode::OsErr as u8, 71);
+        assert_eq!(ExitCode::OsFile as u8, 72);
+        assert_eq!(ExitCode::CantCreat as u8, 73);
+        assert_eq!(ExitCode::IoErr as u8, 74);
+        assert_eq!(ExitCode::TempFail as u8, 75);
+        assert_eq!(ExitCode::Protocol as u8, 76);
+        assert_eq!(ExitCode::NoPerm as u8, 77);
+        assert_eq!(ExitCode::Config as u8, 78);
+    }
+
+    #[test]
+    fn clone() {
         assert_eq!(ExitCode::Ok.clone(), ExitCode::Ok);
     }
 
     #[test]
-    fn copy_exit_code() {
+    fn copy() {
         let a = ExitCode::Ok;
         let b = a;
         assert_eq!(a, b);
     }
 
     #[test]
-    fn debug_exit_code() {
-        assert_eq!(format!("{:?}", ExitCode::Ok), "Ok");
-        assert_eq!(format!("{:?}", ExitCode::Usage), "Usage");
-        assert_eq!(format!("{:?}", ExitCode::DataErr), "DataErr");
-        assert_eq!(format!("{:?}", ExitCode::NoInput), "NoInput");
-        assert_eq!(format!("{:?}", ExitCode::NoUser), "NoUser");
-        assert_eq!(format!("{:?}", ExitCode::NoHost), "NoHost");
-        assert_eq!(format!("{:?}", ExitCode::Unavailable), "Unavailable");
-        assert_eq!(format!("{:?}", ExitCode::Software), "Software");
-        assert_eq!(format!("{:?}", ExitCode::OsErr), "OsErr");
-        assert_eq!(format!("{:?}", ExitCode::OsFile), "OsFile");
-        assert_eq!(format!("{:?}", ExitCode::CantCreat), "CantCreat");
-        assert_eq!(format!("{:?}", ExitCode::IoErr), "IoErr");
-        assert_eq!(format!("{:?}", ExitCode::TempFail), "TempFail");
-        assert_eq!(format!("{:?}", ExitCode::Protocol), "Protocol");
-        assert_eq!(format!("{:?}", ExitCode::NoPerm), "NoPerm");
-        assert_eq!(format!("{:?}", ExitCode::Config), "Config");
+    fn default() {
+        assert_eq!(ExitCode::default(), ExitCode::Ok);
     }
 
     #[test]
     #[allow(clippy::cognitive_complexity, clippy::too_many_lines)]
-    fn exit_code_equality() {
+    fn equality() {
         assert_eq!(ExitCode::Ok, ExitCode::Ok);
         assert_ne!(ExitCode::Ok, ExitCode::Usage);
         assert_ne!(ExitCode::Ok, ExitCode::DataErr);
@@ -595,26 +585,6 @@ mod tests {
         assert_eq!(ExitCode::Config, ExitCode::Config);
     }
 
-    #[test]
-    fn display_exit_code() {
-        assert_eq!(format!("{}", ExitCode::Ok), format!("{}", 0));
-        assert_eq!(format!("{}", ExitCode::Usage), format!("{}", 64));
-        assert_eq!(format!("{}", ExitCode::DataErr), format!("{}", 65));
-        assert_eq!(format!("{}", ExitCode::NoInput), format!("{}", 66));
-        assert_eq!(format!("{}", ExitCode::NoUser), format!("{}", 67));
-        assert_eq!(format!("{}", ExitCode::NoHost), format!("{}", 68));
-        assert_eq!(format!("{}", ExitCode::Unavailable), format!("{}", 69));
-        assert_eq!(format!("{}", ExitCode::Software), format!("{}", 70));
-        assert_eq!(format!("{}", ExitCode::OsErr), format!("{}", 71));
-        assert_eq!(format!("{}", ExitCode::OsFile), format!("{}", 72));
-        assert_eq!(format!("{}", ExitCode::CantCreat), format!("{}", 73));
-        assert_eq!(format!("{}", ExitCode::IoErr), format!("{}", 74));
-        assert_eq!(format!("{}", ExitCode::TempFail), format!("{}", 75));
-        assert_eq!(format!("{}", ExitCode::Protocol), format!("{}", 76));
-        assert_eq!(format!("{}", ExitCode::NoPerm), format!("{}", 77));
-        assert_eq!(format!("{}", ExitCode::Config), format!("{}", 78));
-    }
-
     #[test]
     fn is_success_for_successful_termination() {
         assert!(ExitCode::Ok.is_success());
@@ -639,6 +609,11 @@ mod tests {
         assert!(!ExitCode::Config.is_success());
     }
 
+    #[test]
+    const fn is_success_is_const_fn() {
+        const _: bool = ExitCode::Ok.is_success();
+    }
+
     #[test]
     fn is_failure_for_successful_termination() {
         assert!(!ExitCode::Ok.is_failure());
@@ -663,9 +638,14 @@ mod tests {
         assert!(ExitCode::Config.is_failure());
     }
 
+    #[test]
+    const fn is_failure_is_const_fn() {
+        const _: bool = ExitCode::Ok.is_failure();
+    }
+
     #[cfg(feature = "std")]
     #[test]
-    fn source_exit_code() {
+    fn source() {
         use std::error::Error;
 
         assert!(ExitCode::Ok.source().is_none());
@@ -688,7 +668,7 @@ mod tests {
 
     #[cfg(feature = "std")]
     #[test]
-    fn report_exit_code() {
+    fn report() {
         use std::process::Termination;
 
         assert_eq!(
